commandUnavailableWhileEditingError property

  1. @override
String get commandUnavailableWhileEditingError

The error surfaced when the user taps a slash command while the composer is editing a message.

Implementation

@override
String get commandUnavailableWhileEditingError => 'Not available while editing';