StreamChatLocalizationsFr class

The translations for French (fr).

Inheritance

Constructors

StreamChatLocalizationsFr({String localeName = 'fr'})
Create an instance of the translation bundle for French.
const

Properties

addACommentLabel String
The label for "Add a comment".
no setter
addACommentOrSendLabel String
The label for add a comment or send in case of attachments inside StreamMessageInput
no setter
addAFileLabel String
The label for "add a file"
no setter
addAnOptionLabel String
The label for "Add an option".
no setter
addMoreFilesLabel String
The label for "add more files"
no setter
allowFileAccessMessage String
The message shown for asking file access permission
no setter
allowGalleryAccessMessage String
The message shown for asking gallery access permission
no setter
alsoSendAsDirectMessageLabel String
The label for also send as direct message "checkbox"" in StreamMessageInput
no setter
anonymousPollLabel String
The label for "Anonymous poll".
no setter
askAQuestionLabel String
The label for "Ask a question".
no setter
audioAttachmentText String
The text for audio attachment in channel list preview
no setter
cancelLabel String
The label for "Cancel"
no setter
channelIsMutedText String
The text for showing the channel is muted
no setter
connectedLabel String
The label for "connected" in StreamConnectionStatusBuilder
no setter
connectionErrorDescription String
The description shown when there is no internet connection.
no setter
connectionErrorTitle String
The title shown when there is no internet connection.
no setter
copyMessageLabel String
The label for "copy message"
no setter
couldNotReadBytesFromFileError String
The error shown when the file being read has no bytes
no setter
createLabel String
The label for "Create".
no setter
deleteConversationLabel String
The label for "Delete conversation"
no setter
deleteConversationQuestion String
The question asked while showing delete conversation dialog
no setter
deleteLabel String
The label for "Delete"
no setter
deleteMessageLabel String
The label for "delete message"
no setter
deleteMessageQuestion String
The question asked while showing delete message dialog
no setter
deletePollOptionLabel String
The label for "delete poll option"
no setter
deletePollOptionQuestion String
The question asked while showing delete poll option dialog
no setter
disconnectedLabel String
The label for "disconnected" in StreamConnectionStatusBuilder
no setter
downloadLabel String
The label for "Download"
no setter
draftLabel String
The label for draft message
no setter
editedMessageLabel String
The label for showing the message is edited
no setter
editMessageLabel String
The label for "edit message"
no setter
emptyChatMessagesText String
The text for showing there are no chats
no setter
emptyMessagePreviewText String
The text for empty message previews
no setter
emptyMessagesText String
The text for showing there are empty messages
no setter
enableFileAccessMessage String
The message shown for asking photo and video access permission
no setter
enablePhotoAndVideoAccessMessage String
The message shown for asking photo and video access permission
no setter
endLabel String
The label for "End".
no setter
endVoteConfirmationText String
The confirmation text shown when the user tries to end a poll.
no setter
endVoteLabel String
The label for "End Vote".
no setter
enterANewOptionLabel String
The label for "Enter a new option".
no setter
enterYourCommentLabel String
The label for "Enter your comment".
no setter
fileText String
The text shown for "File"
no setter
flagLabel String
The label for "Flag"
no setter
flagMessageLabel String
The label for "flag message"
no setter
flagMessageQuestion String
The question asked while showing flag message dialog
no setter
flagMessageSuccessfulLabel String
The label for successful message flag
no setter
flagMessageSuccessfulText String
The text for showing the message if successfully flagged
no setter
genericErrorDescription String
The description shown for a generic, uncategorised error.
no setter
genericErrorText String
The text for showing generic error
no setter
genericErrorTitle String
The title shown for a generic, uncategorised error.
no setter
giphyLabel String
The label for "Giphy"
no setter
hashCode int
The hash code for this object.
no setterinherited
holdToRecordLabel String
The label for "Hold to record"
no setter
imageAttachmentText String
The text for image attachment in channel list preview
no setter
instantCommandsLabel String
The label for instant commands in StreamMessageInput
no setter
inText String
The text shown for "In"
no setter
launchUrlError String
The error shown when launchURL fails
no setter
leaveConversationLabel String
The label for "Leave conversation"
no setter
leaveConversationQuestion String
The question asked while showing leave conversation dialog
no setter
leaveGroupLabel String
The label for "Leave Group"
no setter
leaveLabel String
The label for "Leave"
no setter
letsStartChattingLabel String
The label for "let's start chatting"
no setter
linkDisabledDetails String
The additional info on a link disabled error
no setter
linkDisabledError String
The label for a link disabled error
no setter
loadingChannelsError String
The error shown when loading channel fails
no setter
loadingMessagesError String
The error shown when loading messages fails
no setter
loadingPollVotesError String
The label for "Error loading poll votes".
no setter
loadingUsersError String
The error shown when loading users fails
no setter
markAsUnreadLabel String
The text for marking message as unread functionality in MessageWidget
no setter
markUnreadError String
The text of an error shown when marking a message as unread fails
no setter
maximumVotesPerPersonLabel String
The label for "Maximum votes per person".
no setter
messageDeletedLabel String
The label for message deleted
no setter
messageDeletedText String
The text for showing the message is deleted
no setter
messageReactionsLabel String
The label for message reactions
no setter
moderatedMessageBlockedText String
Text shown when a message was blocked by moderation policies
no setter
moderationReviewModalDescription String
The content text of the moderated message warning dialog
no setter
moderationReviewModalTitle String
The title of the moderated message warning dialog
no setter
multipleAnswersLabel String
The label for "Multiple answers".
no setter
noPhotoOrVideoLabel String
The label for showing no photo or video
no setter
noPollVotesLabel String
The label for "There are no poll votes currently".
no setter
noTitleText String
The text for showing there is no title
no setter
noUsersLabel String
The label for showing no users
no setter
offlineLabel String
The label for "Offline"
no setter
okLabel String
The label for "OK"
no setter
onlyVisibleToYouText String
The text for showing if the message is only visible to you
no setter
operationCouldNotBeCompletedText String
The text for showing the operation could not be completed
no setter
photoFromCameraLabel String
The label for "photo from camera"
no setter
photosLabel String
The label for "Photos"
no setter
pollCommentsLabel String
The label for "Poll comments".
no setter
pollOptionDuplicateError String
The error shown when the poll option is a duplicate.
no setter
pollOptionEmptyError String
The error shown when the poll option text is empty.
no setter
pollOptionsLabel String
The label for "Poll Options".
no setter
pollResultsLabel String
The label for "Poll Results".
no setter
pollYouCreatedText String
The text for poll when current user created
no setter
pollYouVotedText String
The text for poll when current user voted
no setter
questionsLabel String
The label for "Questions".
no setter
reconnectingLabel String
The label for "reconnecting" in StreamConnectionStatusBuilder
no setter
repliedToLabel String
The label for "replied to:"
no setter
replyLabel String
The label for "Reply"
no setter
replyToMessageLabel String
The label for "Reply to message"
no setter
retryLabel String
The label for "retry" button
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveImageLabel String
The label for "Save Image"
no setter
saveVideoLabel String
The label for "Save Video"
no setter
searchGifLabel String
The label for search Gif
no setter
searchingForNetworkText String
The text for showing searching for network
no setter
sendAnywayLabel String
The label for "Send Anyway"
no setter
sendingFirstMessageLabel String
The label for sending the first message
no setter
sendLabel String
The label for "Send"
no setter
sendMessagePermissionError String
The label for the MessageInput hint when permission denied on sendMessage
no setter
showInChatLabel String
The label for "Show in chat"
no setter
shuffleLabel String
The label for "Shuffle"
no setter
slideToCancelLabel String
The label for "Slide to cancel"
no setter
slowConnectionErrorDescription String
The description shown when the connection is too slow or the request timed out.
no setter
slowConnectionErrorTitle String
The title shown when the connection is too slow or the request timed out.
no setter
slowModeOnLabel String
The label for slow mode enabled in StreamMessageInput
no setter
somethingWentWrongError String
The error shown when something went wrong
no setter
startAChatLabel String
The label for "start a chat"
no setter
streamChatLabel String
The label for "Stream Chat"
no setter
suggestAnOptionLabel String
The label for "Suggest an option".
no setter
systemMessageLabel String
The label for system message
no setter
threadReplyLabel String
The label for "thread reply"
no setter
todayLabel String
The label for "Today"
no setter
tryAgainLabel String
The label for "Try again"
no setter
updateYourCommentLabel String
The label for "Update your comment".
no setter
uploadAFileLabel String
The label for "upload a file"
no setter
uploadAPhotoLabel String
The label for "upload a photo"
no setter
uploadAVideoLabel String
The label for "upload a video"
no setter
uploadErrorLabel String
The label for "Upload Error"
no setter
userLastOnlineText String
The text for showing the last online of the user
no setter
userOnlineText String
The text for showing user is online
no setter
videoAttachmentText String
The text for video attachment in channel list preview
no setter
videoFromCameraLabel String
The label for "video from camera"
no setter
viewCommentsLabel String
The label for "View Comments".
no setter
viewInfoLabel String
The label for "View Info"
no setter
viewLibrary String
The label for "View library"
no setter
viewResultsLabel String
The label for "View Results".
no setter
voiceRecordingText String
The text for voice recording in channel list preview
no setter
withText String
The label for "With"
no setter
writeAMessageLabel String
The label for write a message in StreamMessageInput
no setter
yesterdayLabel String
The label for "Yesterday"
no setter
youText String
The text shown for "You"
no setter

Methods

attachmentLimitExceedError(int limit) String
Label for "Attachment limit exceeded: it's not possible to add more than $limit attachments"
attachmentsUploadProgressText({required int remaining, required int total}) String
The text for showing the attachments upload progress
createPollLabel({bool isNew = false}) String
The label for "Create poll".
fileTooLargeAfterCompressionError(double limitInMB) String
The error shown in case the file is too large even after compression while uploading via StreamMessageInput
fileTooLargeError(double limitInMB) String
The error shown in case the file is too large while uploading via StreamMessageInput
galleryPaginationText({required int currentPage, required int totalPages}) String
Gallery footer pagination text
maxVotesPerPersonValidationError(int votes, Range<int> range) String?
The error shown when the max votes is not within the range.
membersCountText(int count) String
The text for showing the members count based on count
newThreadsLabel({required int count}) String
The label for "$count new threads"
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optionLabel({bool isPlural = false}) String
The label for "Option".
pinnedByUserText({required User pinnedBy, required User currentUser}) String
The text for showing who pinned the message
pollQuestionValidationError(int length, Range<int> range) String?
The error shown when the poll question length is not within the range.
pollSomeoneCreatedText(String username) String
The text for poll when someone created
pollSomeoneVotedText(String username) String
The text for poll when someone voted
pollVotingModeLabel(PollVotingMode votingMode) String
The label for Poll voting mode.
resultCountText(int count) String
The text for showing the result count in StreamMessageSearchListView
seeAllOptionsLabel({int? count}) String
The label for "See all options".
sentAtText({required DateTime date, required DateTime time}) String
The text for showing on which date and time the message was sent
showAllVotesLabel({int? count}) String
The label for "Show all votes".
threadReplyCountText(int count) String
The text for showing the thread reply count
threadSeparatorText(int replyCount) String
The text for showing the thread separator in case StreamMessageListView contains a parent message
toggleDeleteRetryDeleteMessageText({required bool isDeleteFailed}) String
The text for showing delete/retry-delete based on isDeleteFailed
toggleMuteUnmuteAction({required bool isMuted}) String
The text for "MUTE"/"UNMUTE" based on the value of isMuted.
toggleMuteUnmuteGroupQuestion({required bool isMuted}) String
The text for "Are you sure you want to mute this group?"/"Are you sure you want to unmute this group?" based on the value of isMuted.
toggleMuteUnmuteGroupText({required bool isMuted}) String
The text for "Mute Group"/"Unmute Group" based on the value of isMuted.
toggleMuteUnmuteUserQuestion({required bool isMuted}) String
The text for "Are you sure you want to mute this user?"/"Are you sure you want to unmute this user?" based on the value of isMuted.
toggleMuteUnmuteUserText({required bool isMuted}) String
The text for "Mute User"/"Unmute User" based on the value of isMuted.
togglePinUnpinText({required bool pinned}) String
The text for showing pin/un-pin functionality in MessageWidget based on pinned
toggleResendOrResendEditedMessage({required bool isUpdateFailed}) String
The text for showing resend/resend-edited message based on isUpdateFailed
toString() String
A string representation of this object.
inherited
unreadCountIndicatorLabel({required int unreadCount}) String
The text for unread count indicator
unreadMessagesSeparatorText() String
The text for showing the unread messages count in the StreamMessageListView
userTypingText(Iterable<User> users) String
The text shown when users starts typing
voteCountLabel({int? count}) String
The label for "$count votes".
watchersCountText(int count) String
The text for showing the watchers count based on count

Operators

operator ==(Object other) bool
The equality operator.
inherited